@@ -14,8 +14,7 @@
 #    include <intrin.h>
 #endif
 
-namespace rapidfuzz {
-namespace detail {
+namespace rapidfuzz::detail {
 
 /*
  * shift right without undefined behavior for shifts > bit width
@@ -163,31 +162,16 @@ static inline int countr_zero(uint64_t x)
 }
 #endif
 
-template <typename T, T N, T Pos = 0, bool IsEmpty = (N == 0)>
-struct UnrollImpl;
-
-template <typename T, T N, T Pos>
-struct UnrollImpl<T, N, Pos, false> {
-    template <typename F>
-    static void call(F&& f)
-    {
-        f(Pos);
-        UnrollImpl<T, N - 1, Pos + 1>::call(std::forward<F>(f));
-    }
-};
-
-template <typename T, T N, T Pos>
-struct UnrollImpl<T, N, Pos, true> {
-    template <typename F>
-    static void call(F&&)
-    {}
-};
-
-template <typename T, int N, class F>
-constexpr void unroll(F&& f)
+template <class T, T... inds, class F>
+constexpr void unroll_impl(std::integer_sequence<T, inds...>, F&& f)
 {
-    UnrollImpl<T, N>::call(f);
+    (f(std::integral_constant<T, inds>{}), ...);
 }
 
-} // namespace detail
-} // namespace rapidfuzz
+template <class T, T count, class F>
+constexpr void unroll(F&& f)
+{
+    unroll_impl(std::make_integer_sequence<T, count>{}, std::forward<F>(f));
+}
+
+} // namespace rapidfuzz::detail
