@@ -10,9 +10,9 @@
 
 #include <algorithm>
 #include <array>
+#include <rapidfuzz/details/types.hpp>
 
-namespace rapidfuzz {
-namespace detail {
+namespace rapidfuzz::detail {
 
 template <bool RecordMatrix>
 struct LCSseqResult;
@@ -129,8 +129,7 @@ auto lcs_unroll(const PMV& block, Range<InputIt1>, Range<InputIt2> s2, int64_t s
     unroll<size_t, N>([&](size_t i) { S[i] = ~UINT64_C(0); });
 
     LCSseqResult<RecordMatrix> res;
-    static_if<RecordMatrix>(
-        [&](auto f) { f(res).S = ShiftedBitMatrix<uint64_t>(s2.size(), N, ~UINT64_C(0)); });
+    if constexpr (RecordMatrix) res.S = ShiftedBitMatrix<uint64_t>(s2.size(), N, ~UINT64_C(0));
 
     for (ptrdiff_t i = 0; i < s2.size(); ++i) {
         uint64_t carry = 0;
@@ -140,7 +139,7 @@ auto lcs_unroll(const PMV& block, Range<InputIt1>, Range<InputIt2> s2, int64_t s
             uint64_t x = addc64(S[word], u, carry, &carry);
             S[word] = x | (S[word] - u);
 
-            static_if<RecordMatrix>([&](auto f) { f(res).S[i][word] = S[word]; });
+            if constexpr (RecordMatrix) res.S[i][word] = S[word];
         });
     }
 
@@ -160,8 +159,7 @@ auto lcs_blockwise(const PMV& block, Range<InputIt1>, Range<InputIt2> s2, int64_
     std::vector<uint64_t> S(words, ~UINT64_C(0));
 
     LCSseqResult<RecordMatrix> res;
-    static_if<RecordMatrix>(
-        [&](auto f) { f(res).S = ShiftedBitMatrix<uint64_t>(s2.size(), words, ~UINT64_C(0)); });
+    if constexpr (RecordMatrix) res.S = ShiftedBitMatrix<uint64_t>(s2.size(), words, ~UINT64_C(0));
 
     for (ptrdiff_t i = 0; i < s2.size(); ++i) {
         uint64_t carry = 0;
@@ -174,7 +172,7 @@ auto lcs_blockwise(const PMV& block, Range<InputIt1>, Range<InputIt2> s2, int64_
             uint64_t x = addc64(Stemp, u, carry, &carry);
             S[word] = x | (Stemp - u);
 
-            static_if<RecordMatrix>([&](auto f) { f(res).S[i][word] = S[word]; });
+            if constexpr (RecordMatrix) res.S[i][word] = S[word];
         }
     }
 
@@ -233,7 +231,7 @@ int64_t lcs_seq_similarity(const BlockPatternMatchVector& block, Range<InputIt1>
     if (max_misses >= 5) return longest_common_subsequence(block, s1, s2, score_cutoff);
 
     /* common affix does not effect Levenshtein distance */
-    auto affix = remove_common_affix(s1, s2);
+    StringAffix affix = remove_common_affix(s1, s2);
     int64_t lcs_sim = static_cast<int64_t>(affix.prefix_len + affix.suffix_len);
     if (!s1.empty() && !s2.empty()) lcs_sim += lcs_seq_mbleven2018(s1, s2, score_cutoff - lcs_sim);
 
@@ -258,7 +256,7 @@ int64_t lcs_seq_similarity(Range<InputIt1> s1, Range<InputIt2> s2, int64_t score
     if (max_misses < std::abs(len1 - len2)) return 0;
 
     /* common affix does not effect Levenshtein distance */
-    auto affix = remove_common_affix(s1, s2);
+    StringAffix affix = remove_common_affix(s1, s2);
     int64_t lcs_sim = static_cast<int64_t>(affix.prefix_len + affix.suffix_len);
     if (s1.size() && s2.size()) {
         if (max_misses < 5)
@@ -386,5 +384,4 @@ class LCSseq : public SimilarityBase<LCSseq> {
     }
 };
 
-} // namespace detail
-} // namespace rapidfuzz
\ No newline at end of file
+} // namespace rapidfuzz::detail
