@@ -10,8 +10,7 @@
 
 #include <type_traits>
 
-namespace rapidfuzz {
-namespace fuzz {
+namespace rapidfuzz::fuzz {
 
 /**
  * @defgroup Fuzz Fuzz
@@ -70,13 +69,11 @@ struct CachedRatio {
     CachedIndel<CharT1> cached_indel;
 };
 
-#if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
 template <typename Sentence1>
 CachedRatio(const Sentence1& s1) -> CachedRatio<char_type<Sentence1>>;
 
 template <typename InputIt1>
 CachedRatio(InputIt1 first1, InputIt1 last1) -> CachedRatio<iter_value_t<InputIt1>>;
-#endif
 
 template <typename InputIt1, typename InputIt2>
 ScoreAlignment<double> partial_ratio_alignment(InputIt1 first1, InputIt1 last1, InputIt2 first2,
@@ -128,7 +125,8 @@ struct CachedPartialRatio {
     CachedPartialRatio(InputIt1 first1, InputIt1 last1);
 
     template <typename Sentence1>
-    CachedPartialRatio(const Sentence1& s1_) : CachedPartialRatio(detail::to_begin(s1_), detail::to_end(s1_))
+    explicit CachedPartialRatio(const Sentence1& s1_)
+        : CachedPartialRatio(detail::to_begin(s1_), detail::to_end(s1_))
     {}
 
     template <typename InputIt2>
@@ -143,13 +141,11 @@ private:
     CachedRatio<CharT1> cached_ratio;
 };
 
-#if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
 template <typename Sentence1>
-CachedPartialRatio(const Sentence1& s1) -> CachedPartialRatio<char_type<Sentence1>>;
+explicit CachedPartialRatio(const Sentence1& s1) -> CachedPartialRatio<char_type<Sentence1>>;
 
 template <typename InputIt1>
 CachedPartialRatio(InputIt1 first1, InputIt1 last1) -> CachedPartialRatio<iter_value_t<InputIt1>>;
-#endif
 
 /**
  * @brief Sorts the words in the strings and calculates the fuzz::ratio between
@@ -194,7 +190,8 @@ struct CachedTokenSortRatio {
     {}
 
     template <typename Sentence1>
-    CachedTokenSortRatio(const Sentence1& s1) : CachedTokenSortRatio(detail::to_begin(s1), detail::to_end(s1))
+    explicit CachedTokenSortRatio(const Sentence1& s1)
+        : CachedTokenSortRatio(detail::to_begin(s1), detail::to_end(s1))
     {}
 
     template <typename InputIt2>
@@ -208,13 +205,11 @@ private:
     CachedRatio<CharT1> cached_ratio;
 };
 
-#if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
 template <typename Sentence1>
-CachedTokenSortRatio(const Sentence1& s1) -> CachedTokenSortRatio<char_type<Sentence1>>;
+explicit CachedTokenSortRatio(const Sentence1& s1) -> CachedTokenSortRatio<char_type<Sentence1>>;
 
 template <typename InputIt1>
 CachedTokenSortRatio(InputIt1 first1, InputIt1 last1) -> CachedTokenSortRatio<iter_value_t<InputIt1>>;
-#endif
 
 /**
  * @brief Sorts the words in the strings and calculates the fuzz::partial_ratio
@@ -252,7 +247,7 @@ struct CachedPartialTokenSortRatio {
     {}
 
     template <typename Sentence1>
-    CachedPartialTokenSortRatio(const Sentence1& s1)
+    explicit CachedPartialTokenSortRatio(const Sentence1& s1)
         : CachedPartialTokenSortRatio(detail::to_begin(s1), detail::to_end(s1))
     {}
 
@@ -267,14 +262,13 @@ private:
     CachedPartialRatio<CharT1> cached_partial_ratio;
 };
 
-#if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
 template <typename Sentence1>
-CachedPartialTokenSortRatio(const Sentence1& s1) -> CachedPartialTokenSortRatio<char_type<Sentence1>>;
+explicit CachedPartialTokenSortRatio(const Sentence1& s1)
+    -> CachedPartialTokenSortRatio<char_type<Sentence1>>;
 
 template <typename InputIt1>
 CachedPartialTokenSortRatio(InputIt1 first1, InputIt1 last1)
     -> CachedPartialTokenSortRatio<iter_value_t<InputIt1>>;
-#endif
 
 /**
  * @brief Compares the words in the strings based on unique and common words
@@ -320,7 +314,7 @@ struct CachedTokenSetRatio {
     {}
 
     template <typename Sentence1>
-    CachedTokenSetRatio(const Sentence1& s1_)
+    explicit CachedTokenSetRatio(const Sentence1& s1_)
         : CachedTokenSetRatio(detail::to_begin(s1_), detail::to_end(s1_))
     {}
 
@@ -332,16 +326,14 @@ struct CachedTokenSetRatio {
 
 private:
     std::basic_string<CharT1> s1;
-    SplittedSentenceView<typename std::basic_string<CharT1>::iterator> tokens_s1;
+    detail::SplittedSentenceView<typename std::basic_string<CharT1>::iterator> tokens_s1;
 };
 
-#if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
 template <typename Sentence1>
-CachedTokenSetRatio(const Sentence1& s1) -> CachedTokenSetRatio<char_type<Sentence1>>;
+explicit CachedTokenSetRatio(const Sentence1& s1) -> CachedTokenSetRatio<char_type<Sentence1>>;
 
 template <typename InputIt1>
 CachedTokenSetRatio(InputIt1 first1, InputIt1 last1) -> CachedTokenSetRatio<iter_value_t<InputIt1>>;
-#endif
 
 /**
  * @brief Compares the words in the strings based on unique and common words
@@ -378,7 +370,7 @@ struct CachedPartialTokenSetRatio {
     {}
 
     template <typename Sentence1>
-    CachedPartialTokenSetRatio(const Sentence1& s1_)
+    explicit CachedPartialTokenSetRatio(const Sentence1& s1_)
         : CachedPartialTokenSetRatio(detail::to_begin(s1_), detail::to_end(s1_))
     {}
 
@@ -390,17 +382,15 @@ struct CachedPartialTokenSetRatio {
 
 private:
     std::basic_string<CharT1> s1;
-    SplittedSentenceView<typename std::basic_string<CharT1>::iterator> tokens_s1;
+    detail::SplittedSentenceView<typename std::basic_string<CharT1>::iterator> tokens_s1;
 };
 
-#if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
 template <typename Sentence1>
-CachedPartialTokenSetRatio(const Sentence1& s1) -> CachedPartialTokenSetRatio<char_type<Sentence1>>;
+explicit CachedPartialTokenSetRatio(const Sentence1& s1) -> CachedPartialTokenSetRatio<char_type<Sentence1>>;
 
 template <typename InputIt1>
 CachedPartialTokenSetRatio(InputIt1 first1, InputIt1 last1)
     -> CachedPartialTokenSetRatio<iter_value_t<InputIt1>>;
-#endif
 
 /**
  * @brief Helper method that returns the maximum of fuzz::token_set_ratio and
@@ -439,7 +429,8 @@ struct CachedTokenRatio {
     {}
 
     template <typename Sentence1>
-    CachedTokenRatio(const Sentence1& s1_) : CachedTokenRatio(detail::to_begin(s1_), detail::to_end(s1_))
+    explicit CachedTokenRatio(const Sentence1& s1_)
+        : CachedTokenRatio(detail::to_begin(s1_), detail::to_end(s1_))
     {}
 
     template <typename InputIt2>
@@ -450,18 +441,16 @@ struct CachedTokenRatio {
 
 private:
     std::basic_string<CharT1> s1;
-    SplittedSentenceView<typename std::basic_string<CharT1>::iterator> s1_tokens;
+    detail::SplittedSentenceView<typename std::basic_string<CharT1>::iterator> s1_tokens;
     std::basic_string<CharT1> s1_sorted;
     CachedRatio<CharT1> cached_ratio_s1_sorted;
 };
 
-#if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
 template <typename Sentence1>
-CachedTokenRatio(const Sentence1& s1) -> CachedTokenRatio<char_type<Sentence1>>;
+explicit CachedTokenRatio(const Sentence1& s1) -> CachedTokenRatio<char_type<Sentence1>>;
 
 template <typename InputIt1>
 CachedTokenRatio(InputIt1 first1, InputIt1 last1) -> CachedTokenRatio<iter_value_t<InputIt1>>;
-#endif
 
 /**
  * @brief Helper method that returns the maximum of
@@ -501,7 +490,7 @@ struct CachedPartialTokenRatio {
     {}
 
     template <typename Sentence1>
-    CachedPartialTokenRatio(const Sentence1& s1_)
+    explicit CachedPartialTokenRatio(const Sentence1& s1_)
         : CachedPartialTokenRatio(detail::to_begin(s1_), detail::to_end(s1_))
     {}
 
@@ -513,17 +502,15 @@ struct CachedPartialTokenRatio {
 
 private:
     std::basic_string<CharT1> s1;
-    SplittedSentenceView<typename std::basic_string<CharT1>::iterator> tokens_s1;
+    detail::SplittedSentenceView<typename std::basic_string<CharT1>::iterator> tokens_s1;
     std::basic_string<CharT1> s1_sorted;
 };
 
-#if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
 template <typename Sentence1>
-CachedPartialTokenRatio(const Sentence1& s1) -> CachedPartialTokenRatio<char_type<Sentence1>>;
+explicit CachedPartialTokenRatio(const Sentence1& s1) -> CachedPartialTokenRatio<char_type<Sentence1>>;
 
 template <typename InputIt1>
 CachedPartialTokenRatio(InputIt1 first1, InputIt1 last1) -> CachedPartialTokenRatio<iter_value_t<InputIt1>>;
-#endif
 
 /**
  * @brief Calculates a weighted ratio based on the other ratio algorithms
@@ -556,7 +543,7 @@ double WRatio(const Sentence1& s1, const Sentence2& s2, double score_cutoff = 0)
 template <typename CharT1>
 struct CachedWRatio {
     template <typename InputIt1>
-    CachedWRatio(InputIt1 first1, InputIt1 last1);
+    explicit CachedWRatio(InputIt1 first1, InputIt1 last1);
 
     template <typename Sentence1>
     CachedWRatio(const Sentence1& s1_) : CachedWRatio(detail::to_begin(s1_), detail::to_end(s1_))
@@ -573,18 +560,16 @@ private:
     // multiple times
     std::basic_string<CharT1> s1;
     CachedPartialRatio<CharT1> cached_partial_ratio;
-    SplittedSentenceView<typename std::basic_string<CharT1>::iterator> tokens_s1;
+    detail::SplittedSentenceView<typename std::basic_string<CharT1>::iterator> tokens_s1;
     std::basic_string<CharT1> s1_sorted;
     rapidfuzz::detail::BlockPatternMatchVector blockmap_s1_sorted;
 };
 
-#if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
 template <typename Sentence1>
-CachedWRatio(const Sentence1& s1) -> CachedWRatio<char_type<Sentence1>>;
+explicit CachedWRatio(const Sentence1& s1) -> CachedWRatio<char_type<Sentence1>>;
 
 template <typename InputIt1>
 CachedWRatio(InputIt1 first1, InputIt1 last1) -> CachedWRatio<iter_value_t<InputIt1>>;
-#endif
 
 /**
  * @brief Calculates a quick ratio between two strings using fuzz.ratio
@@ -620,7 +605,7 @@ struct CachedQRatio {
     {}
 
     template <typename Sentence1>
-    CachedQRatio(const Sentence1& s1_) : CachedQRatio(detail::to_begin(s1_), detail::to_end(s1_))
+    explicit CachedQRatio(const Sentence1& s1_) : CachedQRatio(detail::to_begin(s1_), detail::to_end(s1_))
     {}
 
     template <typename InputIt2>
@@ -634,17 +619,14 @@ private:
     CachedRatio<CharT1> cached_ratio;
 };
 
-#if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
 template <typename Sentence1>
-CachedQRatio(const Sentence1& s1) -> CachedQRatio<char_type<Sentence1>>;
+explicit CachedQRatio(const Sentence1& s1) -> CachedQRatio<char_type<Sentence1>>;
 
 template <typename InputIt1>
 CachedQRatio(InputIt1 first1, InputIt1 last1) -> CachedQRatio<iter_value_t<InputIt1>>;
-#endif
 
 /**@}*/
 
-} // namespace fuzz
-} // namespace rapidfuzz
+} // namespace rapidfuzz::fuzz
 
 #include <rapidfuzz/fuzz.impl>
